aboutsummaryrefslogtreecommitdiff
path: root/src/chainparams.cpp
diff options
context:
space:
mode:
authorRoss Nicoll <[email protected]>2021-08-14 10:31:19 +0100
committerRoss Nicoll <[email protected]>2021-08-15 00:28:54 +0100
commit5d0769fc7eb28d1c95c41fc63cee924b91eb265c (patch)
tree541f8013ef09dd8eed013c82b857fd5b00f8c509 /src/chainparams.cpp
parentMerge pull request #2451 from patricklodder/1.14.4-feefilter-rpc (diff)
downloaddiscoin-5d0769fc7eb28d1c95c41fc63cee924b91eb265c.tar.xz
discoin-5d0769fc7eb28d1c95c41fc63cee924b91eb265c.zip
Refresh blockchain checkpoints
Diffstat (limited to 'src/chainparams.cpp')
-rw-r--r--src/chainparams.cpp17
1 files changed, 9 insertions, 8 deletions
diff --git a/src/chainparams.cpp b/src/chainparams.cpp
index c32691be1..f44ea5137 100644
--- a/src/chainparams.cpp
+++ b/src/chainparams.cpp
@@ -198,13 +198,14 @@ public:
( 3250000, uint256S("0x7f3e28bf9e309c4b57a4b70aa64d3b2ea5250ae797af84976ddc420d49684034"))
( 3500000, uint256S("0xeaa303b93c1c64d2b3a2cdcf6ccf21b10cc36626965cc2619661e8e1879abdfb"))
( 3606083, uint256S("0x954c7c66dee51f0a3fb1edb26200b735f5275fe54d9505c76ebd2bcabac36f1e"))
+ ( 3854173, uint256S("0xe4b4ecda4c022406c502a247c0525480268ce7abbbef632796e8ca1646425e75"))
};
chainTxData = ChainTxData{
// Data as of block 954c7c66dee51f0a3fb1edb26200b735f5275fe54d9505c76ebd2bcabac36f1e (height 3606083).
// Tx estimate based on average of year 2021 (~40k transactions per day)
- 1613217680, // * UNIX timestamp of last checkpoint block
- 71035468, // * total number of transactions between genesis and last checkpoint
+ 1628934997, // * UNIX timestamp of last checkpoint block
+ 77616340, // * total number of transactions between genesis and last checkpoint
// (the tx=... number in the SetBestChain debug.log lines)
0.46 // * estimated number of transactions per second after checkpoint
};
@@ -350,14 +351,14 @@ public:
( 2500000, uint256S("0x3a66ec4933fbb348c9b1889aaf2f732fe429fd9a8f74fee6895eae061ac897e2"))
( 2750000, uint256S("0x473ea9f625d59f534ffcc9738ffc58f7b7b1e0e993078614f5484a9505885563"))
( 3062910, uint256S("0x113c41c00934f940a41f99d18b2ad9aefd183a4b7fe80527e1e6c12779bd0246"))
-
+ ( 3286675, uint256S("0x07fef07a255d510297c9189dc96da5f4e41a8184bc979df8294487f07fee1cf3"))
};
chainTxData = ChainTxData{
- // Data as of block a113c41c00934f940a41f99d18b2ad9aefd183a4b7fe80527e1e6c12779bd024 (height 3062910)
- 1613217942, // * UNIX timestamp of last checkpoint block
- 4186373, // * total number of transactions between genesis and last checkpoint
- 0.05 // * estimated number of transactions per second after that timestamp
+ // Data as of block 07fef07a255d510297c9189dc96da5f4e41a8184bc979df8294487f07fee1cf3 (height 3286675)
+ 1628932841, // * UNIX timestamp of last checkpoint block
+ 4469050, // * total number of transactions between genesis and last checkpoint
+ 0.02 // * estimated number of transactions per second after that timestamp
};
}
@@ -198,13 +198,14 @@ public:
};
chainTxData = ChainTxData{
- // Data as of block 954c7c66dee51f0a3fb1edb26200b735f5275fe54d9505c76ebd2bcabac36f1e (height 3606083).
+ // Data as of block e4b4ecda4c022406c502a247c0525480268ce7abbbef632796e8ca1646425e75 (height 3854173).
// Tx estimate based on average of year 2021 (~40k transactions per day)